@@ -52,7 +52,14 @@ sigma2.glmmTMB <- function(object) {
 
 # RE model matrix
 .remodmat <- function(object) UseMethod(".remodmat")
+
 .remodmat.default <- function(object) model.matrix(.ranform(formula(object)), data = model.frame(object))
+.remodmat.merMod <- function(object) {
+    rval <- do.call("cbind", model.matrix(object, type = "randomListRaw"))
+	rval[, !duplicated(colnames(rval)), drop = FALSE]
+}
+
+
 .remodmat.lme <- function(object)
     model.matrix(object$modelStruct$reStruct, data = object$data[rownames(object$fitted), 
 			, drop = FALSE])
@@ -215,16 +222,19 @@ function(object, null, envir = parent.frame(), pj2014 = FALSE, ...) {
     ok <- !is.na(fe)
     fitted <- (model.matrix(object)[, ok, drop = FALSE] %*% fe[ok])[, 1L]
     varFE <- var(fitted)
-    mmRE <- .remodmat(object)
-    
-    # XXX: alternatively:
-    #mmRE <- do.call("cbind", model.matrix(object, type = "randomListRaw"))
-    #varRE <- .varRESum(vc, mmRE[, unique(colnames(mmRE)), drop = FALSE])
-  
-    
+	
+	mmRE <- .remodmat(object) 
     ##Note: Argument 'contrasts' can only be specified for fixed effects
 	##contrasts.arg = eval(cl$contrasts, envir = environment(formula(object))))	
+
 	vc <- .varcorr(object)
+	
+	for(i in seq.int(length(vc))) {
+		a <- fixCoefNames(rownames(vc[[i]]))
+		dimnames(vc[[i]]) <- list(a, a)
+	}
+	colnames(mmRE) <- fixCoefNames(colnames(mmRE))
+
 	if(!all(unlist(sapply(vc, rownames), use.names = FALSE) %in% colnames(mmRE)))
 		stop("RE term names do not match those in model matrix. \n",
 			 "Have 'options(contrasts)' changed since the model was fitted?")
